{"": "", "stdin data": "donn\u00e9es stdin", "Terminal was closed": "Le Terminal a \u00e9t\u00e9 ferm\u00e9", "Run arbitrary scripts": "Ex\u00e9cuter des scripts arbitraires", "Run": "Ex\u00e9cuter", "Name": "Nom", "Script has finished": "L'\u00e9xecution du Script est termin\u00e9", "Copy terminal content": "Copier le contenu du terminal", "Could not launch the script": "Impossible de lancer le script", "Script": "Script", "Terminate": "Terminer", "Terminal": "Terminal", "Terminals": "Terminals", "Done": "Effectu\u00e9", "Open shell terminals": "", "Run a command...": "Ex\u00e9cuter une commande...", "Open a new terminal": "Ouvrir un nouveau terminal", "Starting the script": "D\u00e9marrer le Script", "Script has failed": "L'\u00e9xecution du Script a \u00e9chou\u00e9"}