{"": "", "stdin data": "stdin verisi", "Terminal was closed": "Terminal kapat\u0131ld\u0131", "Run arbitrary scripts": "Rastgele komut dosyas\u0131 \u00e7al\u0131\u015ft\u0131r", "Run": "\u00c7al\u0131\u015ft\u0131r", "Name": "Ad\u0131", "Script has finished": "Betik tamamland\u0131", "Copy terminal content": "Terminal i\u00e7eri\u011fini kopyala", "Could not launch the script": "Betik ba\u015flat\u0131lamad\u0131", "Script": "Script", "Terminate": "Sonland\u0131r", "Terminal": "Terminal", "Terminals": "Terminaller", "Done": "Bitti", "Open shell terminals": "U\u00e7birimi a\u00e7", "Run a command...": "Bir komut \u00e7al\u0131\u015ft\u0131r\u0131n...", "Open a new terminal": "Yeni terminal a\u00e7", "Starting the script": "Betik ba\u015flat\u0131l\u0131yor", "Script has failed": "Betik ba\u015far\u0131s\u0131z oldu"}