{"": "", "stdin data": "stdin-Daten", "Terminal was closed": "Terminal wurde geschlossen", "Run arbitrary scripts": "Beliebige Skripte ausf\u00fchren", "Run": "Ausf\u00fchren", "Name": "Name", "Script has finished": "Skript ist abgeschlossen", "Copy terminal content": "Terminal-Inhalt kopieren", "Could not launch the script": "Das Skript konnte nicht gestartet werden", "Script": "Skript", "Terminate": "Beenden", "Terminal": "Terminal", "Terminals": "Terminals", "Done": "Fertig", "Open shell terminals": "Shell-Terminals \u00f6ffnen", "Run a command...": "Einen Befehl ausf\u00fchren...", "Open a new terminal": "Neues Terminal \u00f6ffnen", "Starting the script": "Starten des Skriptes", "Script has failed": "Skript ist fehlgeschlagen"}