{"": "", "stdin data": "stdin-gegevens", "Terminal was closed": "", "Run arbitrary scripts": "", "Run": "Uitvoeren", "Name": "Naam", "Script has finished": "Script is voltooid", "Copy terminal content": "Terminal inhoud kopi\u00ebren", "Could not launch the script": "Kan het script niet starten", "Script": "Script", "Terminate": "Be\u00ebindigen", "Terminal": "Terminal", "Terminals": "Terminals", "Done": "Gereed", "Open shell terminals": "", "Run a command...": "Een opdracht uitvoeren...", "Open a new terminal": "Open een nieuwe terminal", "Starting the script": "", "Script has failed": "Script is mislukt"}