{"": "", "stdin data": "stdin \u6570\u636e", "Terminal was closed": "\u7ec8\u7aef\u5df2\u5173\u95ed", "Run arbitrary scripts": "\u8fd0\u884c\u4efb\u610f\u811a\u672c", "Run": "\u8fd0\u884c", "Name": "\u540d\u79f0", "Script has finished": "\u811a\u672c\u5df2\u5b8c\u6210", "Copy terminal content": "\u590d\u5236\u7ec8\u7aef\u5185\u5bb9", "Could not launch the script": "\u65e0\u6cd5\u542f\u52a8\u811a\u672c", "Script": "\u811a\u672c", "Terminate": "\u7ec8\u6b62", "Terminal": "\u7ec8\u7aef", "Terminals": "\u7ec8\u7aef", "Done": "\u5df2\u5b8c\u6210", "Open shell terminals": "\u6253\u5f00 shell \u7ec8\u7aef", "Run a command...": "\u8fd0\u884c\u547d\u4ee4......", "Open a new terminal": "\u6253\u5f00\u4e00\u4e2a\u65b0\u7684\u7ec8\u7aef", "Starting the script": "\u542f\u52a8\u811a\u672c", "Script has failed": "\u811a\u672c\u5df2\u5931\u8d25"}