{"": "", "stdin data": "data standardn\u00edho vstupu", "Terminal was closed": "Termin\u00e1l byl ukon\u010den", "Run arbitrary scripts": "Spustit libovoln\u00e9 skripty", "Run": "Spustit", "Name": "Jm\u00e9no", "Script has finished": "Skript byl dokon\u010den", "Copy terminal content": "Kop\u00edrovat obsah termin\u00e1lu", "Could not launch the script": "Nelze spustit skript", "Script": "Skript", "Terminate": "Ukon\u010dit", "Terminal": "Termin\u00e1l", "Terminals": "Termin\u00e1ly", "Done": "Hotovo", "Open shell terminals": "Otev\u0159en\u00e9 shell termin\u00e1ly", "Run a command...": "Spustit p\u0159\u00edkaz...", "Open a new terminal": "Otev\u0159\u00edt nov\u00fd termin\u00e1l", "Starting the script": "Spou\u0161t\u011bn\u00ed skriptu", "Script has failed": "Skript se nepoda\u0159ilo dokon\u010dit"}